#[repr(u8)]pub enum FilterBit0 {
FILTER_BIT0_0 = 0,
FILTER_BIT0_1 = 1,
}Variants
FILTER_BIT0_0 = 0
Filter after 7th bit for all Commands Op Codes that need to be filtered.
FILTER_BIT0_1 = 1
Filter after 8th bit for all Read/Write Op Codes that are filtered based on the address.
Implementations
Sourceimpl FilterBit0
impl FilterBit0