#[repr(u8)]pub enum FilterBit1 {
FILTER_BIT3_0 = 0,
FILTER_BIT3_1 = 1,
}Variants
FILTER_BIT3_0 = 0
Filter after 7th bit for all Commands Op Codes that need to be filtered.
FILTER_BIT3_1 = 1
Filter after 8th bit for all Read/Write Op Codes that are filtered based on the address.
Implementations
Sourceimpl FilterBit1
impl FilterBit1