#[repr(u8)]pub enum P0ByteSelMd {
P0_BYTE_SEL_MD0 = 0,
P0_BYTE_SEL_MD1 = 1,
}Variants
P0_BYTE_SEL_MD0 = 0
Normal Operation. The Address byte mode is determined by the Op Code Command
P0_BYTE_SEL_MD1 = 1
Sets the Byte Mode to 3-byte and gives control of the function to the P0_BYTE_SEL in the P0 Filter Control Register. In this mode, any changes to P0_BYTE_SEL are latched and the internal state of BYTE_SEL will retain this value when P0_BYTE_SEL_MD is cleared
Implementations
Sourceimpl P0ByteSelMd
impl P0ByteSelMd