#[repr(u8)]pub enum P0Dirty {
P0_DIRTY_0 = 0,
P0_DIRTY_1 = 1,
}Variants
P0_DIRTY_0 = 0
Indicates normal operation. No Writes have been directed to the inactive Flash
P0_DIRTY_1 = 1
Indicates that a write to the inactive Flash has been detected and the state of the flash should be considered “dirty”.
Implementations