#[repr(u8)]pub enum P0DirtyInt {
P0_DIRTY_INT0 = 0,
P0_DIRTY_INT1 = 1,
}Variants
P0_DIRTY_INT0 = 0
Indicates normal operation
P0_DIRTY_INT1 = 1
Indicates that a write has occurred to the FW Code region of the inactive Flash and that flash is now considered corrupt.
Implementations
Sourceimpl P0DirtyInt
impl P0DirtyInt