#[repr(u8)]pub enum P0WeByteMd {
P0_WE_BYTE_MD0 = 0,
P0_WE_BYTE_MD1 = 1,
}Variants
P0_WE_BYTE_MD0 = 0
Write Enable command is not required to switch address byte mode
P0_WE_BYTE_MD1 = 1
Write Enable command is required prior to switching address byte mode
Implementations
Sourceimpl P0WeByteMd
impl P0WeByteMd