#[repr(u8)]pub enum P1ActSel {
P1_ACT_SEL0 = 0,
P1_ACT_SEL1 = 1,
}Variants
P1_ACT_SEL0 = 0
Sets CS0 as the read location for the firmware image and sets CS1 as the write location for the FW image.
P1_ACT_SEL1 = 1
Sets CS1 as the read location for the firmware image and sets CS0 as the write location for the FW image.
Implementations