#[repr(u8)]pub enum P1ByteSelMd {
P1_BYTE_SEL_MD0 = 0,
P1_BYTE_SEL_MD1 = 1,
}Variants
P1_BYTE_SEL_MD0 = 0
Normal Operation. The Address byte mode is determined by the Op Code Command.
P1_BYTE_SEL_MD1 = 1
Sets the Byte Mode to 3-byte and gives control of the function to the P1_BYTE_SEL in the P1 Filter Control Register. In this mode, any changes to P1_BYTE_SEL are latched and the internal state of P1_BYTE_SEL will retain this value when P1_BYTE_SEL_MD is cleared.
Implementations
Sourceimpl P1ByteSelMd
impl P1ByteSelMd