#[repr(u8)]pub enum P1DirtyInt {
P1_DIRTY_INT0 = 0,
P1_DIRTY_INT1 = 1,
}Variants
P1_DIRTY_INT0 = 0
Indicates normal operation
P1_DIRTY_INT1 = 1
indicates that a write has occurred to the FW Code region of the inactive Flash and that flash is now considered corrupt
Implementations
Sourceimpl P1DirtyInt
impl P1DirtyInt