#[repr(u8)]pub enum P1WeByteMd {
P1_WE_BYTE_MD0 = 0,
P1_WE_BYTE_MD1 = 1,
}Variants
P1_WE_BYTE_MD0 = 0
Write Enable command is not required to switch address byte mode.
P1_WE_BYTE_MD1 = 1
Write Enable command is required prior to switching address byte mode.
Implementations
Sourceimpl P1WeByteMd
impl P1WeByteMd