#[repr(u8)]pub enum P0FltEn {
FLT_DISABLE = 0,
FLT_ENABLE = 1,
}Variants
FLT_DISABLE = 0
Filter Disabled. All CS Disable outputs are asserted so that host access to the flash devices is disabled. CS# inputs to the filter are disabled so that the filter state machine is locked in its current state. All other register controls can be accessed, but have no impact on the functionality of the filter while the filter is disabled.
FLT_ENABLE = 1
Filter Enabled. CS# inputs to the filter are enabled and the filter state machine controls the CS disable outputs. CS# inputs to the filter are enabled so that the filter state machine is active. All other register controls are functional. The filter is enabled by default at CPLD power on.
Implementations