#[repr(u8)]pub enum P1FltEn {
FLT_DISABLE = 0,
FLT_ENABLE = 1,
}Variants
FLT_DISABLE = 0
Filter Disabled. All CS Disable outputs are asserted so that host access to the flash devices is disabled. CS# inputs to the filter are disabled so that the filter state machine is locked in its current state. All register controls are functional.
FLT_ENABLE = 1
Filter Enabled. CS# inputs to the filter are enabled and the filter state machine controls the CS disable outputs. This bit takes priority over the P1_BYP_EN bit in the Test Register. Setting this bit enables filtering and enables communication to flash devices regardless of the state of P1_BYP_EN. All other register controls are functional while filtering is enabled. The filter is enabled by default at CPLD power on.
Implementations